Tutorials and Resources
=======================

Since Pygame Turbo is a fork of Pygame Zero, resources that were made for it can
be useful when working with Pygame Zero too.

Here are some tutorials and learning resources which use Pygame Zero.


Books
-----

* `Coding Games in Python`_ (DK) - teaches programming in Python from scratch
  with Pygame Zero and bright, colourful illustrations.

* `Code the Classics`_ (Raspberry Pi Press) - covers the history of classic
  computer games and explains how to make them with Pygame Zero.

* `Mission Python`_ (No Starch Press) - takes you through the process of writing
  one larger game with Pygame Zero.


.. _`Coding Games in Python`: https://www.dk.com/us/book/9781465473615-coding-games-in-python/
.. _`Code the Classics`: https://store.rpipress.cc/products/code-the-classics
.. _`Mission Python`: https://nostarch.com/missionpython


Online Tutorials
----------------

* `Simple Game Tutorials`_ is a collection of step-by-step tutorials which guide
  you through the process of making some simple games.

* `Coding Games with Pygame Zero and Python`_ - teaches programming in Python
  for complete beginners, moving into several complete examples.

* `Game Development with Pygame Zero`_ - walks through creating several
  small, fun games.


.. _`Simple Game Tutorials`: https://simplegametutorials.github.io/pygamezero/
.. _`Coding Games with Pygame Zero and Python`: https://electronstudio.github.io/pygame-zero-book/
.. _`Game Development with Pygame Zero`: https://aposteriori.trinket.io/game-development-with-pygame-zero


Magazines
---------

* MagPi_, the Raspberry Pi magazine, has covered Pygame Zero several times.
  MagPi is available in print but is also free to download online.
* Wireframe_, also from Raspberry Pi, and also free to download online, is a
  magazine focused on games, game development, and the game industry, and most
  issues contain Pygame Zero examples.

.. _MagPi: https://magpi.raspberrypi.org/articles/pygame-zero-invaders
.. _Wireframe: https://wireframe.raspberrypi.org/


Video Tutorials
---------------

There are numerous Pygame Zero tutorial videos on YouTube_; here are some:

* `A brief introduction to Pygame Zero <https://www.youtube.com/watch?v=Qd35oQXwkf0>`_ (Neil Muller)
* `How to use Pygame Zero <https://www.youtube.com/watch?v=qAbPMXH7V0k>`_ (TeCoEd)

.. _YouTube: https://www.youtube.com/


Hardware
--------

* Phidgets_ make a range of electronic devices - sensors, motors, input devices,
  and more - that connect to your computer over USB and can be used from Python
  programs. They have a `range of Pygame Zero projects for you to try`__ with
  Phidgets, and they offer a discount for educators.

.. _Phidgets: https://www.phidgets.com
.. __: https://www.phidgets.com/education/learn/projects/pygame-zero-projects/
